(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common'), require('@angular/platform-browser'), require('@angular/http'), require('rxjs/add/operator/toPromise')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', '@angular/common', '@angular/platform-browser', '@angular/http', 'rxjs/add/operator/toPromise'], factory) :
	(factory((global.ng = global.ng || {}, global.ng['alaska-common'] = {}),global.ng.core,global.ng.common,global.ng['platform-browser'],global.ng.http));
}(this, (function (exports,core,common,platformBrowser,http) { 'use strict';

var SafePipe = /** @class */ (function () {
    function SafePipe(_sanitizer) {
        this._sanitizer = _sanitizer;
    }
    SafePipe.prototype.transform = function (value, args) {
        var type = args[0].toString();
        switch (type) {
            case 'html':
                return this._sanitizer.bypassSecurityTrustHtml(value);
            case 'style':
                return this._sanitizer.bypassSecurityTrustStyle(value);
            case 'script':
                return this._sanitizer.bypassSecurityTrustScript(value);
            case 'url':
                return this._sanitizer.bypassSecurityTrustUrl(value);
            case 'resourceUrl':
                return this._sanitizer.bypassSecurityTrustResourceUrl(value);
            default:
                throw new Error("Unable to bypass security for invalid type: " + type);
        }
    };
    SafePipe.decorators = [
        { type: core.Pipe, args: [{
                    name: 'safe'
                },] },
    ];
    /** @nocollapse */
    SafePipe.ctorParameters = function () { return [
        { type: platformBrowser.DomSanitizer, },
    ]; };
    return SafePipe;
}());

var SafeHtmlPipe = /** @class */ (function () {
    function SafeHtmlPipe(_sanitizer) {
        this._sanitizer = _sanitizer;
    }
    SafeHtmlPipe.prototype.transform = function (value, args) {
        return this._sanitizer.bypassSecurityTrustHtml(value);
    };
    SafeHtmlPipe.decorators = [
        { type: core.Pipe, args: [{
                    name: 'safeHtml'
                },] },
    ];
    /** @nocollapse */
    SafeHtmlPipe.ctorParameters = function () { return [
        { type: platformBrowser.DomSanitizer, },
    ]; };
    return SafeHtmlPipe;
}());

var SafeScriptPipe = /** @class */ (function () {
    function SafeScriptPipe(_sanitizer) {
        this._sanitizer = _sanitizer;
    }
    SafeScriptPipe.prototype.transform = function (value, args) {
        return this._sanitizer.bypassSecurityTrustScript(value);
    };
    SafeScriptPipe.decorators = [
        { type: core.Pipe, args: [{
                    name: 'safeScript'
                },] },
    ];
    /** @nocollapse */
    SafeScriptPipe.ctorParameters = function () { return [
        { type: platformBrowser.DomSanitizer, },
    ]; };
    return SafeScriptPipe;
}());

var SafeStylePipe = /** @class */ (function () {
    function SafeStylePipe(_sanitizer) {
        this._sanitizer = _sanitizer;
    }
    SafeStylePipe.prototype.transform = function (value, args) {
        return this._sanitizer.bypassSecurityTrustStyle(value);
    };
    SafeStylePipe.decorators = [
        { type: core.Pipe, args: [{
                    name: 'safeStyle'
                },] },
    ];
    /** @nocollapse */
    SafeStylePipe.ctorParameters = function () { return [
        { type: platformBrowser.DomSanitizer, },
    ]; };
    return SafeStylePipe;
}());

var UriUtil = /** @class */ (function () {
    function UriUtil() {
    }
    UriUtil.prototype.formatUri = function (basePath, queryParameters) {
        var params = [];
        for (var key in queryParameters) {
            params.push(key + "=" + encodeURIComponent(queryParameters[key]));
        }
        return basePath + "?" + params.join("&");
    };
    UriUtil.decorators = [
        { type: core.Injectable },
    ];
    /** @nocollapse */
    UriUtil.ctorParameters = function () { return []; };
    return UriUtil;
}());

var EditorialContentsService = /** @class */ (function () {
    function EditorialContentsService(http$$1, uriUtil) {
        this.http = http$$1;
        this.uriUtil = uriUtil;
        this.heroesUrl = '/umbraco/alaskaHeadlessCms/contents';
    }
    EditorialContentsService.prototype.getComponentData = function (id) {
        var url = this.uriUtil.formatUri(this.heroesUrl + '/getComponent', {
            id: id,
            includeData: true,
            includeRendering: false
        });
        return this.http.get(url)
            .toPromise()
            .then(function (response) { return JSON.parse(response.json().data); })
            .catch(this.handleError);
    };
    EditorialContentsService.prototype.getComponent = function (id, includeData, includeRendering) {
        var url = this.uriUtil.formatUri(this.heroesUrl + '/getComponent', {
            id: id,
            includeData: includeData,
            includeRendering: includeRendering
        });
        return this.http.get(url)
            .toPromise()
            .then(function (response) { return response.json(); })
            .catch(this.handleError);
    };
    EditorialContentsService.prototype.getPage = function (id, includeData, includeRendering) {
        var url = this.uriUtil.formatUri(this.heroesUrl + '/getPage', {
            id: id,
            includeData: includeData,
            includeRendering: includeRendering
        });
        return this.http.get(url)
            .toPromise()
            .then(function (response) { return response.json(); })
            .catch(this.handleError);
    };
    EditorialContentsService.prototype.getSite = function (id) {
        var url = this.uriUtil.formatUri(this.heroesUrl + '/getSite', {
            id: id
        });
        return this.http.get(url)
            .toPromise()
            .then(function (response) { return response.json(); })
            .catch(this.handleError);
    };
    EditorialContentsService.prototype.handleError = function (error) {
        console.error(error);
        return Promise.reject(error.message || error);
    };
    EditorialContentsService.decorators = [
        { type: core.Injectable },
    ];
    /** @nocollapse */
    EditorialContentsService.ctorParameters = function () { return [
        { type: http.Http, },
        { type: UriUtil, },
    ]; };
    return EditorialContentsService;
}());

var EditorialComponentComponent = /** @class */ (function () {
    function EditorialComponentComponent(contentsService) {
        this.contentsService = contentsService;
    }
    EditorialComponentComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.contentsService.getComponent(this.id, false, true)
            .then(function (component) { return _this.initializeComponent(component); });
    };
    EditorialComponentComponent.prototype.initializeComponent = function (component) {
        this.component = component;
        if (component.rendering.js) {
            var script = document.createElement('script');
            script.innerText = '$( document ).ready(function() { ' + component.rendering.js + '});';
            document.body.appendChild(script);
        }
    };
    EditorialComponentComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'app-editorial-component',
                    templateUrl: './editorial-component.component.html',
                    styleUrls: ['./editorial-component.component.css']
                },] },
    ];
    /** @nocollapse */
    EditorialComponentComponent.ctorParameters = function () { return [
        { type: EditorialContentsService, },
    ]; };
    EditorialComponentComponent.propDecorators = {
        'id': [{ type: core.Input },],
    };
    return EditorialComponentComponent;
}());

var EditorialPageComponent = /** @class */ (function () {
    function EditorialPageComponent(location, contentsService) {
        this.location = location;
        this.contentsService = contentsService;
    }
    EditorialPageComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.pageId = this.getPageId();
        if (!this.pageId) {
            //page not found handler
            return;
        }
        this.contentsService.getPage(this.pageId, false, true)
            .then(function (page) { return _this.page = page; });
    };
    EditorialPageComponent.prototype.getPageId = function () {
        if (this.id) {
            return this.id;
        }
        return location.pathname;
    };
    EditorialPageComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'app-editorial-page',
                    templateUrl: './editorial-page.component.html',
                    styleUrls: ['./editorial-page.component.css']
                },] },
    ];
    /** @nocollapse */
    EditorialPageComponent.ctorParameters = function () { return [
        { type: common.Location, },
        { type: EditorialContentsService, },
    ]; };
    EditorialPageComponent.propDecorators = {
        'id': [{ type: core.Input },],
    };
    return EditorialPageComponent;
}());

var AlaskaCommonModule = /** @class */ (function () {
    function AlaskaCommonModule() {
    }
    AlaskaCommonModule.forRoot = function () {
        return {
            ngModule: AlaskaCommonModule,
            providers: [UriUtil, EditorialContentsService]
        };
    };
    AlaskaCommonModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        common.CommonModule
                    ],
                    exports: [SafePipe, SafeHtmlPipe, SafeScriptPipe, SafeStylePipe, EditorialComponentComponent, EditorialPageComponent],
                    declarations: [SafePipe, SafeHtmlPipe, SafeScriptPipe, SafeStylePipe, EditorialComponentComponent, EditorialPageComponent]
                },] },
    ];
    /** @nocollapse */
    AlaskaCommonModule.ctorParameters = function () { return []; };
    return AlaskaCommonModule;
}());

exports.AlaskaCommonModule = AlaskaCommonModule;
exports.EditorialComponentComponent = EditorialComponentComponent;
exports.EditorialPageComponent = EditorialPageComponent;
exports.SafePipe = SafePipe;
exports.SafeHtmlPipe = SafeHtmlPipe;
exports.SafeScriptPipe = SafeScriptPipe;
exports.SafeStylePipe = SafeStylePipe;
exports.EditorialContentsService = EditorialContentsService;
exports.UriUtil = UriUtil;

Object.defineProperty(exports, '__esModule', { value: true });

})));
